@@ -1,7 +1,7 @@
 /** @file
 	Parser: includes all Configure-d headers
 
-	Copyright (c) 2001-2012 Art. Lebedev Studio (http://www.artlebedev.com)
+	Copyright (c) 2001-2015 Art. Lebedev Studio (http://www.artlebedev.com)
 	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
 
 	when used Configure [HAVE_CONFIG_H] it uses defines from Configure,
@@ -192,28 +192,21 @@ inline size_t min(size_t a, size_t b){ return a<b?a:b; }
 #define THREAD_LOCAL // __thread // multithreading support required only for apache2 module
 #endif
 
+#if __clang__
+#pragma clang diagnostic ignored "-Wparentheses"       // if(a=b)
+#pragma clang diagnostic ignored "-Winline-new-delete" // replacement operator cannot be declared 'inline'
+#endif
+
 #if _MSC_VER
-
 #pragma warning(disable:4355)  // using this in calls to parent constructors
-
 #pragma warning(disable:4291)  // no matching operator delete found; memory will not be freed if initialization throws an exception
-
-#pragma warning(disable:4786)  // identifier was truncated to '255' characters in the debug information
-
-#pragma warning(disable:4511)  // copy constructor could not be generated
-
 #pragma warning(disable:4512)  // assignment operator could not be generated
-
 #pragma warning(disable:4505)  // unreferenced local function has been removed
-
 #pragma warning(disable:4127)  // conditional expression is constant; while(true) OK
-
 #pragma warning(disable:4706)  // assignment within conditional expression if(type var=somethig) OK
-
 #pragma warning(disable:4996)  // memcpy deprecation
-
 #pragma warning(disable:4702)  // unreachable code
-
+#pragma warning(disable:4511)  // copy constructor could not be generated (vs2003 specific)
 #endif
 
 /// to debug backtrace pointers switch this on:
