@@ -1,14 +1,14 @@
 /** @file
 	Parser: directory scanning for different OS-es decls.
 
-	Copyright (c) 2000-2012 Art. Lebedev Studio (http://www.artlebedev.com)
+	Copyright (c) 2000-2015 Art. Lebedev Studio (http://www.artlebedev.com)
 	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
 */
 
 #ifndef PA_DIR_H
 #define PA_DIR_H
 
-#define IDENT_PA_DIR_H "$Id: pa_dir.h,v 1.25 2013/07/22 20:55:54 moko Exp $"
+#define IDENT_PA_DIR_H "$Id: pa_dir.h,v 1.27 2015/10/26 01:21:55 moko Exp $"
 
 #include "pa_config_includes.h"
 
@@ -37,8 +37,7 @@ struct ffblk {
 	/*helper*/
 	HANDLE handle;
 
-	void stat_file(){}
-	bool is_dir();
+	bool is_dir(bool);
 	double size();
 	time_t c_timestamp();
 	time_t m_timestamp();
@@ -59,12 +58,9 @@ struct ffblk {
 
 #ifdef HAVE_STRUCT_DIRENT_D_TYPE
 	unsigned char _d_type;
-	void stat_file();
-#else
-	void stat_file(){}
-	void real_stat_file();
 #endif
-	bool is_dir();
+	bool is_dir(bool);
+	void stat_file();
 	double size();
 	time_t c_timestamp();
 	time_t m_timestamp();
