@@ -1,7 +1,7 @@
 /** @file
 	Parser: hash class decl.
 
-	Copyright (c) 2001-2012 Art. Lebedev Studio (http://www.artlebedev.com)
+	Copyright (c) 2001-2015 Art. Lebedev Studio (http://www.artlebedev.com)
 
 	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
 */
@@ -17,7 +17,7 @@
 #ifndef PA_HASH_H
 #define PA_HASH_H
 
-#define IDENT_PA_HASH_H "$Id: pa_hash.h,v 1.85 2013/08/21 12:11:14 moko Exp $"
+#define IDENT_PA_HASH_H "$Id: pa_hash.h,v 1.94 2015/10/26 01:21:55 moko Exp $"
 
 #include "pa_memory.h"
 #include "pa_types.h"
@@ -90,11 +90,13 @@ inline uint hash_code(int self) {
 #undef HASH
 #undef HASH_STRING
 #undef HASH_NEW_PAIR
+#undef HASH_ORDER_CLEAR
 #undef HASH_FOR_EACH
 
 #define HASH OrderedHash
 #define HASH_STRING OrderedHashString
 #define HASH_NEW_PAIR(code, key, value) *ref=new Pair(code, key, value, *ref, this->last); this->last=&((*ref)->next)
+#define HASH_ORDER_CLEAR() first=0; last=&first
 
 #define HASH_FOR_EACH \
 	for(Pair *pair=this->first; pair; pair=pair->next)
@@ -104,6 +106,7 @@ inline uint hash_code(int self) {
 #define HASH Hash
 #define HASH_STRING HashString
 #define HASH_NEW_PAIR(code, key, value) *ref=new Pair(code, key, value, *ref)
+#define HASH_ORDER_CLEAR()
 
 #define HASH_FOR_EACH \
 	Pair **ref=this->refs; \
@@ -113,19 +116,17 @@ inline uint hash_code(int self) {
 #endif
 
 template<typename K, typename V> class HASH: public PA_Object {
+protected:
+	class Pair;
 public:
-
 	typedef K key_type;
 	typedef V value_type;
 
 	HASH() { 
 		allocated=Hash_allocates[allocates_index=0];
 		fpairs_count=fused_refs=0;
-		refs=new(UseGC) Pair*[allocated];
-#ifdef HASH_ORDER
-		first=0;
-		last=&first;
-#endif
+		refs=new Pair*[allocated];
+		HASH_ORDER_CLEAR();
 	}
 
 	HASH(const HASH& source) {
@@ -133,11 +134,10 @@ public:
 		allocated=source.allocated;
 		fused_refs=source.fused_refs;
 		fpairs_count=source.fpairs_count;
-		refs=new(UseGC) Pair*[allocated];
+		refs=new Pair*[allocated];
 		// clone & rehash
 #ifdef HASH_ORDER
-		first=0;
-		last=&first;
+		HASH_ORDER_CLEAR();
 		for(Pair *pair=source.first; pair; pair=pair->next)
 		{
 			uint index=pair->code%allocated;
@@ -244,14 +244,47 @@ public:
 	}
 
 #ifdef HASH_ORDER
+	String::Body first_key() const {
+#ifdef HASH_CODE_CACHING
+		return (first) ? String::Body(first->key, first->code) : String::Body();
+#else
+		return (first) ? first->key : String::Body();
+#endif
+	}
+
 	V first_value() const {
 		return (first) ? first->value : V(0);
 	}
 
+	String::Body last_key() const {
+		if (fpairs_count) {
+			Pair* pair = (Pair*)((char *)last - offsetof(Pair, next));
+#ifdef HASH_CODE_CACHING
+			return String::Body(pair->key, pair->code);
+#else
+			return pair->key;
+#endif
+		} else {
+			return String::Body();
+		}
+	}
+
 	V last_value() const {
 		return (fpairs_count) ? ((Pair *)((char *)last - offsetof(Pair, next)))->value : V(0);
 	}
-#endif
+
+	void order_clear() {
+		HASH_ORDER_CLEAR();
+	}
+
+	void order_next(Pair* pair) {
+		pair->prev=last;
+		pair->next=0;
+		*last=pair;
+		last=&(pair->next);
+	}
+
+#endif //HASH_ORDER
 
 	/// put a [value] under the [key] if that [key] existed @returns existed or not
 	bool put_replaced(K key, V value) {
@@ -335,11 +368,8 @@ public:
 	/// remove all elements
 	void clear() {
 		memset(refs, 0, sizeof(*refs)*allocated);
-		fpairs_count=fused_refs=0;	
-#ifdef HASH_ORDER
-		first=0;
-		last=&first;
-#endif
+		fpairs_count=fused_refs=0;
+		HASH_ORDER_CLEAR();
 	}
 
 protected:
@@ -390,7 +420,7 @@ protected:
 		if (allocates_index<HASH_ALLOCATES_COUNT-1) allocates_index++;
 		// allocated bigger refs array
 		allocated=Hash_allocates[allocates_index];
-		refs=new(UseGC) Pair*[allocated];
+		refs=new Pair*[allocated];
 
 		// rehash
 		Pair **old_ref=old_refs;
@@ -510,6 +540,22 @@ public:
 		return V(0);
 	}
 
+	/// get associated [value] by the [key], optimized
+	V get(const char *key) const {
+		uint code=0;
+		if(key && *key){
+			generic_hash_code(code, key);
+		} else {
+			key=0;
+		}
+		uint index=code%this->allocated;
+		for(Pair *pair=this->refs[index]; pair; pair=pair->link)
+			if(pair->code==code && CORD_cmp(pair->key,(CORD)key)==0)
+				return pair->value;
+
+		return V(0);
+	}
+
 	/// put a [value] under the [key] if that [key] existed @returns existed or not
 	bool put_replaced(K str, V value) {
 		if(!value) {
@@ -589,37 +635,69 @@ public:
 		return V(0);
 	}
 
+#else //HASH_CODE_CACHING
+
+template<typename V> class HASH_STRING: public HASH<const String::Body,V>{
+public:
+	typedef typename HASH<const String::Body,V>::Pair Pair;
+
+#endif //HASH_CODE_CACHING
+
 	/// simple hash iterator
 	class Iterator {
 		const HASH_STRING<V>& fhash;
 		Pair *fcurrent;
+#ifndef HASH_ORDER
+		int i;
+#endif
 	public:
+#ifdef HASH_ORDER
 		Iterator(const HASH_STRING<V>& ahash): fhash(ahash) {
 			fcurrent=fhash.first;
 		}
 
-		operator bool () {
-			return fcurrent != 0;
-		}
-
 		void next() {
 			fcurrent=fcurrent->next;
 		}
+#else
+		Iterator(const HASH_STRING<V>& ahash): fhash(ahash) {
+			fcurrent=0;
+			for(i=0; i<fhash.allocated; i++)
+				if (fcurrent=fhash.refs[i])
+					break;
+		}
+
+		void next() {
+			if(fcurrent=fcurrent->link)
+				return;
+			for(i++; i<fhash.allocated; i++)
+				if (fcurrent=fhash.refs[i])
+					break;
+		}
+#endif
+
+		operator bool () {
+			return fcurrent != 0;
+		}
 
 		String::Body key(){
+#ifdef HASH_CODE_CACHING
 			return String::Body(fcurrent->key, fcurrent->code);
+#else
+			return fcurrent->key;
+#endif
 		}
 
 		V value(){
 			return fcurrent->value;
 		}
+
+		Pair *pair(){
+			return fcurrent;
+		}
 	};
+
 };
-#else //HASH_CODE_CACHING
-
-template<typename V> class HASH_STRING: public HASH<const String::Body,V>{};
-
-#endif //HASH_CODE_CACHING
 
 #ifndef HASH_ORDER
 ///    Auto-object used to temporarily substituting/removing string hash values
