@@ -1,14 +1,14 @@
 /** @file
 	Parser: request info class decl.
 
-	Copyright (c) 2001-2012 Art. Lebedev Studio (http://www.artlebedev.com)
+	Copyright (c) 2001-2015 Art. Lebedev Studio (http://www.artlebedev.com)
 	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
 */
 
 #ifndef PA_REQUEST_INFO_H
 #define PA_REQUEST_INFO_H
 
-#define IDENT_PA_REQUEST_INFO_H "$Id: pa_request_info.h,v 1.7 2012/03/16 09:24:10 moko Exp $"
+#define IDENT_PA_REQUEST_INFO_H "$Id: pa_request_info.h,v 1.9 2015/10/26 01:21:56 moko Exp $"
 
 /// some information from web server
 class Request_info {
@@ -30,6 +30,16 @@ public:
 	//@{ these are filed by Request class itself: user's post data
 	const char* post_data;  size_t post_size;
 	//@}
+
+	// misha@ Probably it's a good idea to move this method into targets, but de facto the only POST and PUT can have the body and all targets should support it
+	bool can_have_body(){
+		return
+			method
+			&& (
+				strcasecmp(method, "POST") == 0
+				|| strcasecmp(method, "PUT") == 0
+			);
+	}
 };
 
 #endif
