@@ -1,14 +1,14 @@
 /** @file
 	Parser: table class decl.
 
-	Copyright (c) 2001-2012 Art. Lebedev Studio (http://www.artlebedev.com)
+	Copyright (c) 2001-2015 Art. Lebedev Studio (http://www.artlebedev.com)
 	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
 */
 
 #ifndef PA_TABLE_H
 #define PA_TABLE_H
 
-#define IDENT_PA_TABLE_H "$Id: pa_table.h,v 1.64 2012/03/16 09:24:11 moko Exp $"
+#define IDENT_PA_TABLE_H "$Id: pa_table.h,v 1.69 2015/10/26 01:21:56 moko Exp $"
 
 #include "pa_types.h"
 #include "pa_hash.h"
@@ -50,7 +50,10 @@ public:
 	size_t current() const { return fcurrent; }
 	void offset(bool absolute, int offset);
 
- 	/** @return column index from @a column_name. '<0' if no such column
+	/// @return checks all rows to find maximum cells number
+	size_t max_cells() const;
+
+	/** @return column index from @a column_name. '<0' if no such column
 		if no such - 'bark'
 	*/
 	int column_name2index(const String& column, bool bark) const;
@@ -58,6 +61,12 @@ public:
 	/// @return item from @a column
 	const String* item(size_t column);
 
+	/// sets @a column value
+	void put_item(size_t column, const String*);
+
+	/// removes current row
+	void remove_current();
+
 	/// @return item from @a column. '0' if no such column
 	const String* item(const String& column) {
 		int index=column_name2index(column, false);
