@@ -18,13 +18,10 @@
  * cord_basics.
  */
 /* Boehm, December 8, 1995 1:53 pm PST */
+
 #include "pa_config_includes.h"
-# include <stdio.h>
-# include <string.h>
-# include <stdlib.h>
-# include <stdarg.h>
-# include "cord.h"
-# include "ec.h"
+#include "cord.h"
+#include "ec.h"
 
 # define I_HIDE_POINTERS	/* So we get access to allocation lock.	*/
 				/* We use this for lazy file reading, 	*/
