@@ -1,14 +1,14 @@
 /** @file
 	Parser: @b console class decl.
 
-	Copyright (c) 2001-2012 Art. Lebedev Studio (http://www.artlebedev.com)
+	Copyright (c) 2001-2015 Art. Lebedev Studio (http://www.artlebedev.com)
 	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
 */
 
 #ifndef PA_VCONSOLE_H
 #define PA_VCONSOLE_H
 
-#define IDENT_PA_VCONSOLE_H "$Id: pa_vconsole.h,v 1.19 2013/10/04 21:21:56 moko Exp $"
+#define IDENT_PA_VCONSOLE_H "$Id: pa_vconsole.h,v 1.22 2015/10/26 01:22:01 moko Exp $"
 
 // includes
 
@@ -32,17 +32,18 @@ public: // Value
 	/// VConsole: 0
 	VStateless_class *get_class() { return 0; }
 
-	/// console: line, CLASS, CLASS_NAME
+	/// console: line
 	Value* get_element(const String& aname) {
 		// $line
 		if(aname==CONSOLE_LINE_NAME) {
 			char local_value[MAX_STRING];
 			if(fgets(local_value, sizeof(local_value), stdin))
-				return new VString(*new String(strdup(local_value), String::L_TAINTED));
+				return new VString(*new String(pa_strdup(local_value), String::L_TAINTED));
 
 			return 0; // EOF
 		}
 
+#ifndef OPTIMIZE_BYTECODE_GET_ELEMENT__SPECIAL
 		// $CLASS
 		if(aname==CLASS_NAME)
 			return this;
@@ -50,6 +51,7 @@ public: // Value
 		// $CLASS_NAME
 		if(aname==CLASS_NAMETEXT)
 			return new VString(console_class_name);
+#endif
 
 		throw Exception(PARSER_RUNTIME,
 			&aname,
