@@ -1,14 +1,14 @@
 /** @file
 	Parser: @b form class decls.
 
-	Copyright (c) 2001-2012 Art. Lebedev Studio (http://www.artlebedev.com)
+	Copyright (c) 2001-2015 Art. Lebedev Studio (http://www.artlebedev.com)
 	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
 */
 
 #ifndef PA_VFORM_H
 #define PA_VFORM_H
 
-#define IDENT_PA_VFORM_H "$Id: pa_vform.h,v 1.60 2013/07/16 15:21:06 moko Exp $"
+#define IDENT_PA_VFORM_H "$Id: pa_vform.h,v 1.64 2015/10/26 01:22:01 moko Exp $"
 
 // includes
 
@@ -54,9 +54,9 @@ public: // Value
 	
 	const char* type() const { return "form"; }
 	
-	// form: CLASS,CLASS_NAME,fields,tables,files,imap,method,field
+	// form: fields,tables,files,imap,method,field
 	Value* get_element(const String& aname);
-	Charset* get_post_charset();
+	Charset* get_body_charset();
 
 public: // usage
 
@@ -67,8 +67,8 @@ private:
 	Request_charsets& fcharsets;
 	Request_info& frequest_info;
 
-	bool is_post;
-	bool is_post_charset_detected;
+	bool can_have_body;
+	bool charset_detected;
 	POST_CONTENT_TYPE post_content_type;
 
 	char *strpart(const char* str, size_t len);
