@@ -1,14 +1,14 @@
 /**	@file
 	Parser: @b object class decl.
 
-	Copyright (c) 2001-2012 Art. Lebedev Studio (http://www.artlebedev.com)
+	Copyright (c) 2001-2015 Art. Lebedev Studio (http://www.artlebedev.com)
 	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
 */
 
 #ifndef PA_VOBJECT_H
 #define PA_VOBJECT_H
 
-#define IDENT_PA_VOBJECT_H "$Id: pa_vobject.h,v 1.62 2013/10/08 21:25:46 moko Exp $"
+#define IDENT_PA_VOBJECT_H "$Id: pa_vobject.h,v 1.64 2015/10/26 01:22:02 moko Exp $"
 
 // includes
 
@@ -58,6 +58,9 @@ public: // Value
 
 	override Value* get_element(const String& aname);
 	override const VJunction* put_element(const String& name, Value* value);
+#ifdef FEATURE_GET_ELEMENT4CALL
+	override Value* get_element4call(const String& aname);
+#endif
 
 	override const String* get_json_string(Json_options& options);
 
