@@ -1,14 +1,14 @@
 /** @file
 	Parser: stateless class decls.
 
-	Copyright (c) 2001-2012 Art. Lebedev Studio (http://www.artlebedev.com)
+	Copyright (c) 2001-2015 Art. Lebedev Studio (http://www.artlebedev.com)
 	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
 */
 
 #ifndef PA_VSTATELESS_CLASS_H
 #define PA_VSTATELESS_CLASS_H
 
-#define IDENT_PA_VSTATELESS_CLASS_H "$Id: pa_vstateless_class.h,v 1.75 2013/10/04 21:21:57 moko Exp $"
+#define IDENT_PA_VSTATELESS_CLASS_H "$Id: pa_vstateless_class.h,v 1.78 2015/10/26 01:22:02 moko Exp $"
 
 // include
 
@@ -20,8 +20,10 @@
 // defines
 
 #define CLASS_NAME "CLASS"
+#ifndef OPTIMIZE_BYTECODE_GET_ELEMENT__SPECIAL
 #define CLASS_NAMETEXT "CLASS_NAME"
 extern const String class_name, class_nametext;
+#endif
 
 // forwards
 
@@ -195,7 +197,7 @@ public: // usage
 	VStateless_class* base_class() { return fbase; }
 
 	bool derived_from(VStateless_class& vclass){
-		return fbase==&vclass || fbase && fbase->derived_from(vclass);
+		return fbase==&vclass || ( fbase && fbase->derived_from(vclass) );
 	}
 
 	/// @returns new value for current class, used in classes/ & VClass
