@@ -1,14 +1,14 @@
 /** @file
 	Parser: @b table parser class decl.
 
-	Copyright (c) 2001-2012 Art. Lebedev Studio (http://www.artlebedev.com)
+	Copyright (c) 2001-2015 Art. Lebedev Studio (http://www.artlebedev.com)
 	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
 */
 
 #ifndef PA_VTABLE_H
 #define PA_VTABLE_H
 
-#define IDENT_PA_VTABLE_H "$Id: pa_vtable.h,v 1.61 2013/03/09 06:20:40 misha Exp $"
+#define IDENT_PA_VTABLE_H "$Id: pa_vtable.h,v 1.64 2015/10/26 01:22:03 moko Exp $"
 
 #include "pa_vstateless_object.h"
 #include "pa_table.h"
@@ -46,6 +46,12 @@ public: // Value
 	override Table* get_table() { return ftable; }
 	/// VTable: columns,methods
 	override Value* get_element(const String& aname);
+#ifdef FEATURE_GET_ELEMENT4CALL
+	/// VTable: methods,columns
+	override Value* get_element4call(const String& aname);
+#endif
+	/// VTable: columns
+	virtual const VJunction* put_element(const String&, Value*);
 
 public: // usage
 
