@@ -1,14 +1,14 @@
 /** @file
 	Parser: @b void parser class.
 
-	Copyright (c) 2001-2012 Art. Lebedev Studio (http://www.artlebedev.com)
+	Copyright (c) 2001-2015 Art. Lebedev Studio (http://www.artlebedev.com)
 	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
 */
 
 #ifndef PA_VVOID_H
 #define PA_VVOID_H
 
-#define IDENT_PA_VVOID_H "$Id: pa_vvoid.h,v 1.40 2012/05/28 20:22:08 moko Exp $"
+#define IDENT_PA_VVOID_H "$Id: pa_vvoid.h,v 1.42 2015/10/26 01:22:03 moko Exp $"
 
 #define STRICT_VARS
 
@@ -30,9 +30,14 @@ public: // Value
 	override bool is_void() const { return true; }
 
 	/// VVoid: json-string ("null")
-	override const String* get_json_string(Json_options&) {
-		static const String singleton_json_null(String("null"));
-		return &singleton_json_null;
+	override const String* get_json_string(Json_options& options) {
+		if(options.fvoid == Json_options::V_STRING){
+			static const String singleton_json_empty_string(String("\"\""));
+			return &singleton_json_empty_string;
+		} else {
+			static const String singleton_json_null(String("null"));
+			return &singleton_json_null;
+		}
 	}
 
 	/// VVoid: methods
