@@ -1,22 +1,20 @@
 /** @file
 	Parser: @b xnode parser class decl.
 
-	Copyright (c) 2001-2012 Art. Lebedev Studio (http://www.artlebedev.com)
+	Copyright (c) 2001-2015 Art. Lebedev Studio (http://www.artlebedev.com)
 	Author: Alexandr Petrosian <paf@design.ru> (http://paf.design.ru)
 */
 
 #ifndef PA_VXNODE_H
 #define PA_VXNODE_H
 
-#define IDENT_PA_VXNODE_H "$Id: pa_vxnode.h,v 1.43 2013/10/04 21:21:58 moko Exp $"
+#define IDENT_PA_VXNODE_H "$Id: pa_vxnode.h,v 1.47 2015/10/26 01:22:03 moko Exp $"
 
 #include "classes.h"
 #include "pa_common.h"
 #include "pa_vstateless_object.h"
 
-extern "C" {
 #include "libxml/tree.h"
-};
 
 // defines
 
@@ -43,7 +41,7 @@ public: // Value
 	/// VXnode: true	 
 	override Value& as_expr_result();
 
-	/// VXnode: $CLASS,$method, fields
+	/// VXnode: $method, fields
 	override Value* get_element(const String& aname);
 
 	/// VXnode: $nodeValue
